import React, { Fragment } from 'react';
import { Row, Col } from 'reactstrap';
import Helpers from '../utils/Helpers';
import SitePagination from './SitePagination';
import DropdownActions from './DropdownActions';
import LoadingTbody from './LoadingTbody';

export default class DataTable extends React.Component {
  constructor(props) {
    super(props);
  }

  render() {
    return <Fragment>
      <Row className={`${this.props.containerClass ? this.props.containerClass : '' }`}>
        <Col>
          <table className="table table-bordered table-striped">
            <thead>
              <tr>
                {Object.keys(this.props.columnValueProcs).map((columnName) => {
                  return <th key={Helpers.randomNumber}>
                    {columnName}
                  </th>
                })}
                {this.props.actions && <th>
                  Actions
                </th>}
              </tr>
            </thead>
            <tbody>
              {!this.props.rows && <LoadingTbody columnHeaders={Object.keys(this.props.columnValueProcs)}/>}
              {this.props.rows && <Fragment>
                {this.props.rows.map((row) => {
                  return <tr key={Helpers.randomNumber}>
                    {Object.keys(this.props.columnValueProcs).map((columnName) => {
                      return <td key={Helpers.randomNumber}>
                        {this.getColumnValue(row, columnName)}
                      </td>
                    })}
                  </tr>
                })}
                {this.props.actions && <th>
                  <DropdownActions actions={this.props.actions} pageComponent={this.props.pageComponent}/>
                </th>}
              </Fragment>}
            </tbody>
          </table>
        </Col>
      </Row>
      {this.props.pegable && <Row className="mt-3">
        <Col>
          {this.props.pegable.totalPages > 0 && <SitePagination pageComponent={this} pegable={this.props.pegable} paginationPath={this.props.paginationPath} className="float-end"/>}
        </Col>
      </Row>}
    </Fragment>
  }

  getColumnValue = (row, columnName) => {
    if(typeof this.props.columnValueProcs[columnName] === "function") {
      return this.props.columnValueProcs[columnName](row);
    } else {
      return row[columnName];
    }
  }
}
