import BaseModel from './BaseModel';

export default class Transaction extends BaseModel {
  static search = (currentUser, searchParams, pageNo, pageSize) => {
    pageNo = !pageNo ? 0 : (pageNo - 1)
    pageSize = !pageSize ? 10 : (pageSize > 20 ? 10 : 0)
    if(!searchParams) {
      searchParams = {
        "filterType": "DEFAULT",  
        "pageNo": pageNo,
        "pageSize": pageSize,
        "partnerId": currentUser.partnerId
      }
    } else {
      searchParams.pageNo = pageNo
      searchParams.pageSize = pageSize
    }
    return this.signedPost(`/v1/freight/trnsearch`, searchParams, currentUser.authToken)
  }

  static fetchByBpiLogId = (currentUser, transactionType, bpiLogId) => {
    return this.signedGet(`/v1/trnlog/${bpiLogId}/${transactionType}`, {}, currentUser.authToken)
  }

  saveStatusData = (currentUser, data) => {
    return Transaction.signedPut(`/v1/edi${this.ediVersionId}`, data, currentUser.authToken)
  }

  static fetchTrail = (currentUser, bpiLogId) => {
    return this.signedGet(`/v1/trail/${bpiLogId}`, {}, currentUser.authToken)
  }

  static dummyResponse = (pageNumber, perPage) => {
    pageNumber = parseInt(pageNumber);
    perPage = parseInt(perPage);
    return {
      data: {
        meta: {
          page: pageNumber,
          per_page: 10,
          total_records: 99
        },
        transactions: this.dummyTransactions(pageNumber, perPage)
      }
    }
  }

  static dummyTransactions = (pageNumber, perPage) => {
    let arr = [];
    for (var inx = 1; inx <= perPage; inx++) {
      arr.push(new Transaction(this.dummyTransaction(((pageNumber - 1) * perPage) + inx)));
    }
    return arr;
  }

  static dummyTransaction(id) {
    let random = parseInt(Math.random() * 10) % 3;
    let transactionType = [204, 210, 214][random];
    return {
      "tsuCode": 1,
      "senderPartnerId": "70000020",
      "receiverPartnerId": "70000021",
      "senderIsaId": "NTGROUP211     ",
      "receiverIsaId": "GMCORP800      ",
      "bpiLogId": id,
      "invoiceNumber": "PRONUMBER",
      "invoiceDate": "20040805",
      "deliveryDate": "20040809",
      "deliveryDateQualifier": "017",
      "stControlNumber": "Transaction ID Num",
      "shipmentNumber": "Shipment ID Number12",
      "shipmentDate": "20040805",
      "scacCode": "CNWY",
      "proNumber": "Reference Identification",
      "datafileTypeId": 1,
      "ediTypeId": 5,
      "ediVersionId": transactionType,
      "createdBy": "70000020",
      "createdDate": "2021-06-28 12:29:22",
      "status": 1,
      "payMethod": "PP",
      "lstFreightHeaderAddress": [
        {
          "headerAddId": 1,
          "addressCode": "SH",
          "addressLine1": "Address Information",
          "city": "City Name",
          "zipCode": "Postal Code",
          "state": "St",
          "country": "US",
          "contactPersonName": ""
        },
        {
          "headerAddId": 2,
          "addressCode": "CN",
          "addressLine1": "Address Information",
          "city": "City Name",
          "zipCode": "Postal Code",
          "state": "St",
          "country": "US",
          "contactPersonName": ""
        },
        {
          "headerAddId": 3,
          "addressCode": "BT",
          "addressLine1": "Address Information",
          "city": "City Name",
          "zipCode": "Postal Code",
          "state": "St",
          "country": "US",
          "contactPersonName": ""
        }
      ],
      "freightHeaderMessage": {
        "headerMessageId": 1,
        "messageCode": "",
        "message": ""
      },
      "lstFreightLine": [
        {
          "bpiLineId": 1,
          "itemNumber": "1",
          "itemDescription": "Lading Description continued",
          "itemWeightQualifier": "G",
          "itemWeight": "2442",
          "itemQuantity": 509,
          "itemQuantityQualifier": "BDL",
          "itemWeightUnitCode": "L",
          "itemCharge": 325.41,
          "itemChargeQualifier": "FR",
          "itemTotalCharge": "32541",
          "tariffCode": "CNWY",
          "tariffNumber": "5350",
          "classCode": "55"
        },
        {
          "bpiLineId": 2,
          "itemNumber": "2",
          "itemDescription": "XPO DISCOUNT SAVES YOU",
          "itemQuantity": 0,
          "itemChargeQualifier": "",
          "itemTotalCharge": "-4023",
          "itemChargeAllowanceCode": "DSC",
          "tariffCode": "CNWY",
          "tariffNumber": "5350"
        },
        {
          "bpiLineId": 3,
          "itemNumber": "3",
          "itemDescription": "FSC FUEL SURCHARGE 8.30% ....",
          "itemQuantity": 0,
          "itemCharge": 30.82,
          "itemChargeQualifier": "FR",
          "itemTotalCharge": "3082",
          "itemChargeAllowanceCode": "FUE",
          "tariffCode": "CNWY",
          "tariffNumber": "110"
        }
      ],
      "freightSummary": {
        "summId": 1,
        "weight": "2442",
        "invoiceNetAmount": "27409",
        "qualifier": "G",
        "freightRate": 10484,
        "freightRateQualifier": "MN",
        "freightCharge": 27409,
        "ladingQuantity": 509,
        "ladingQuantityCode": "L",
        "totalLines": 3
      },
      "isacontrolNumber": "000000025"
    }
  }
}
