import BaseModel from './BaseModel';
import Partner from './Partner';
import moment from 'moment';

export default class User extends BaseModel {
  fullName = () => {
    return [this.firstName, this.middleName, this.lastName].filter(
      (item) => item !== null && item !== undefined && item.toString().trim() !== ''
    ).join(' ');
  }

  static authenticateByEmailPassword = (email, password) => {
    let data = {
      "userName" : email,
      "password" : password
    }
    return this.unsignedPost(`/auth/token`, data, false)
  }

  static authenticate2Fa = (email, otp) => {
    return this.unsignedPost(`/2fa/${email}/${otp}`, {});
  }

  static afterAuthenticationByEmailPasswordSuccess = (response) => {
    if(response.data.statusCode === "000") {
      let { authToken, result } = response.data;
      let userDetails = result;
      userDetails.authToken = authToken;
      this.currentUser = userDetails;
    }
  }

  static authenticate = (authToken) => {
    return this.fetchUserByAuthToken(authToken)
  }

  static afterTokenValidationSuccess = (response, authToken) => {
    let { data } = response;
    let userDetails = data[0];
    userDetails.authToken = authToken;
    userDetails.authenticationDate = moment().format("YYYY-MM-DD HH:mm:ss");
    let partnerDetails = data[1];
    this.currentUser = userDetails;
    Partner.currentPartner = partnerDetails;
  }

  static isAuthenticatedWithInLast24Hours = () => {
    if(!User.currentUser) { return false };

    return moment().subtract(1, "day") < moment(User.currentUser.authenticationDate)
  }

  static signOut = () => {
    delete localStorage[BaseModel.getLocalStorageKey('CurrentUser')];
    delete localStorage[BaseModel.getLocalStorageKey('CurrentPartner')];
    delete localStorage[BaseModel.getLocalStorageKey('AssociatedPartners')];
  }

  static fetchUserByAuthToken = (authToken) => {
    return this.unsignedGet(
      `/auth/validate/${authToken}`, {}
    )
  }

  static set currentUser(userDetails) {
    localStorage.setItem(BaseModel.getLocalStorageKey('CurrentUser'), JSON.stringify(userDetails));
  }

  static get currentUser() {
    let userDetails = localStorage.getItem(BaseModel.getLocalStorageKey('CurrentUser'));
    if(userDetails) {
      return new User(JSON.parse(userDetails));
    } else {
      return null
    }
  }
}
